/*
    This file is part of Gabriel's Qt/QML CardBoard Sample (or short GQQCS)

    GQQCS is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    GQQCS is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Foobar.  If not, see <http://www.gnu.org/licenses/>.

    Updated: 07/08/2015 by: Gabriel F.
*/

import QtQuick 2.4

Rectangle {
    id: root
    anchors.fill: parent
    color: "#bb000000"
    opacity: 0.0
    visible: false

    NumberAnimation {
        id: fadeIn
        target: root
        property: "opacity"
        duration: 1000
        easing.type: Easing.InOutQuad
        to: 1.0
        onStarted: { root.visible = true }
    }

    NumberAnimation {
        id: fadeOut
        target: root
        property: "opacity"
        duration: 1000
        easing.type: Easing.InOutQuad
        to: 0.0
        onStopped: { root.visible = false }
    }

    function show() { fadeIn.start() }
    function hide() { fadeOut.start() }


    Rectangle {
        color: "#004c80"
        gradient: Gradient {
            GradientStop {
                position: 0.00;
                color: "#bb004c80";
            }
            GradientStop {
                position: 1.00;
                color: "#bb3f667e";
            }
        }
        width: parent.width*0.95
        height: parent.height*0.95
        radius: height*0.05
        anchors.centerIn: parent

        Rectangle {
            width: parent.width*0.03
            height: width
            color: "#bb000000"
            border.width: height*0.05
            border.color: "white"
            Text {
                font.pixelSize: parent.height*0.9
                text: "X"
                font.bold: true
                anchors.centerIn: parent
                color: "white"
            }
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.topMargin: width
            anchors.leftMargin: width
        }

        Text {
            id: titulo
            text: "Gabriel's Qt/QML Cardboard VR Sample"
            font.bold: true
            width: parent.width*0.9
            height: titulo.contentHeight
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            anchors.top: parent.top
            anchors.topMargin: parent.height*0.08
            anchors.horizontalCenter: parent.horizontalCenter
            font.pixelSize: parent.height*0.08
            color: "white"
        }
        Text {
            id: description
            text: localeHelper.getSymbol("SobreAppBig")
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: parent.height*0.05
            width: parent.width*0.9
            height: contentHeight
            wrapMode: Text.WordWrap
            anchors.top: titulo.bottom
            anchors.topMargin: parent.height*0.08
            anchors.horizontalCenter: parent.horizontalCenter
            color: "white"
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                hide()
            }
        }

        Rectangle {
            id: linkPetrec
            anchors.top: description.bottom
            anchors.topMargin: parent.height*0.08
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width*0.9
            height: parent.height*0.1
            radius: height*0.2
            color: "#bb000000"
            Text {
                id: web
                text: "http://www.gabrieldesign.com.br"
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: parent.height*0.5
                width: parent.width*0.95
                anchors.centerIn: parent
                color: "white"
            }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    Qt.openUrlExternally("http://www.gabrieldesign.com.br")
                }
            }
        }
        Text {
            id: description2
            text: localeHelper.getSymbol("SobreAppGAF")
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: parent.height*0.04
            width: parent.width*0.9
            height: contentHeight
            wrapMode: Text.WordWrap
            anchors.top: linkPetrec.bottom
            anchors.topMargin: parent.height*0.08
            anchors.horizontalCenter: parent.horizontalCenter
            color: "white"
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    Qt.openUrlExternally("http://gaf.impa.br")
                }
            }
        }

    }


}

